=====
Vyper
=====

.. toctree::
    :maxdepth: 2

    Overview <index.rst>

.. toctree::
    :caption: Getting Started
    :maxdepth: 2

    installing-vyper.rst
    vyper-by-example.rst

.. toctree::
    :caption: Language Description
    :maxdepth: 2

    structure-of-a-contract.rst
    types.rst
    constants-and-vars.rst
    statements.rst
    control-structures.rst
    scoping-and-declarations.rst
    built-in-functions.rst
    interfaces.rst
    event-logging.rst
    natspec.rst

.. toctree::
    :caption: Using the Compiler
    :maxdepth: 2

    compiling-a-contract.rst
    compiler-exceptions.rst
    deploying-contracts.rst
    testing-contracts.rst

.. toctree::
    :caption: Additional Resources
    :maxdepth: 2

    resources
    release-notes.rst
    contributing.rst
    style-guide.rst
    versioning.rst
